# Changelog

## v0.7.10

- feat: new `with_overrides` in `WhatsAppBotConfig` class to allow creation with only changing certain parameters of it.

- fix: more complex structured output types to `CerebrasGenerationProvider` provider are now properlly propagated to the API.


